@@ -14,12 +14,17 @@ ________________________________
 
 import socket
 import pickle
-import netifaces as ni
+# import netifaces as ni
 
 # def client():
 HEADER = 64
 
-print("Client CLI")
+print("______________________________________________________")
+print("                                                ")
+print("Pyserved CLI Client")
+print("")
+print("Enter the host and port in the fields below.")
+
 # PORT = 5050
 
 FORMAT = 'utf-8'
@@ -78,6 +83,9 @@ def clientd(file_path):
     text = read(file_path)
     send(text)
 
-
+print("Now enter the path of file which you want to send")
 path = input("File path:")
 clientd(path)
+
+print("")
+print("______________________________________________________")
\ No newline at end of file
