@@ -41,9 +41,7 @@ elif osofmachine=="linux":
 
 try:
     os.mkdir(SAVE_DIR)
-except OSError as exc:
-    if exc.errno != errno.EEXIST:
-        raise
+except:
     pass
 
 
